@@ -14,6 +14,8 @@
    "British Virgin Islands"                       => "Virgin Islands, British",
    "Brunei"                                       => "Brunei Darussalam",
    "Burma"                                        => "Myanmar",
+   "China, Hong Kong Special Administrative Region" => "Hong Kong",
+   "China, Macao Special Administrative Region"   => "Macao",
    "Cocos Islands"                                => "Cocos (Keeling) Islands",
    "Congo (Brazzaville)"                          => "Congo",
    "Democratic People's Republic of Korea"        => "Korea, Democratic People's Republic of",
@@ -31,6 +33,7 @@
    "Hong Kong Special Administrative Region of China" => "Hong Kong",
    "Iran (Islamic Republic of)"                   => "Iran, Islamic Republic of",
    "Iran"                                         => "Iran, Islamic Republic of",
+   "Kazakstan"                                    => "Kazakhstan",
    "Keeling Islands"                              => "Cocos (Keeling) Islands",
    "Libya"                                        => "Libyan Arab Jamahiriya",
    "Macao Special Administrative Region of China" => "Macao",
@@ -41,10 +44,11 @@
    "Micronesia (Federated States of)"             => "Micronesia, Federated States of",
    "North Korea"                                  => "Korea, Democratic People's Republic of",
    "Occupied Palestinian Territory"               => "Palestinian Territory, Occupied",
-   "Pitcairn Islands"                             => "Pitcairn",
    "Pitcairn Island"                              => "Pitcairn",
+   "Pitcairn Islands"                             => "Pitcairn",
    "Republic of Korea"                            => "Korea, Republic of",
    "Republic of Moldova"                          => "Moldova, Republic of",
+   "Saint Helena"                                 => "Saint Helena, Ascension and Tristan da Cunha",
    "Saint-Barthelemy"                             => "Saint Barthelemy",
    "Saint-Martin (French part)"                   => "Saint Martin",
    "South Korea"                                  => "Korea, Republic of",
@@ -69,7 +73,6 @@
    "Virgin Islands (US)"                          => "Virgin Islands, U.S.",
    "Virgin Islands"                               => "Virgin Islands, U.S.",
    "Wallis and Futuna Islands"                    => "Wallis and Futuna",
-   "Kazakstan"                                    => "Kazakhstan",
   );
 
 # From v. 2.xx:
@@ -268,7 +271,7 @@
    "RUSSIAN FEDERATION"                           => "Russian Federation",
    "RWANDA"                                       => "Rwanda",
    "SAINT BARTHLEMY"                             => "Saint Barthelemy",
-   "SAINT HELENA"                                 => "Saint Helena",
+   "SAINT HELENA, ASCENSION AND TRISTAN DA CUNHA" => "Saint Helena, Ascension and Tristan da Cunha",
    "SAINT KITTS AND NEVIS"                        => "Saint Kitts and Nevis",
    "SAINT LUCIA"                                  => "Saint Lucia",
    "SAINT MARTIN"                                 => "Saint Martin",
